@@ -8,6 +8,7 @@ import time
 import matplotlib.pyplot as plt
 from geoh5py.workspace import Workspace
 from geoh5py.objects import Points, Curve, Surface
+from geoh5py.groups import ContainerGroup
 from ipywidgets import (
     Dropdown,
     ColorPicker,
@@ -19,6 +20,7 @@ from ipywidgets import (
     FloatText,
     VBox,
     HBox,
+    Box,
     ToggleButton,
     ToggleButtons,
     interactive_output,
@@ -56,197 +58,59 @@ class EMLineProfiler(ObjectDataSelection):
         },
         "objects": "Data_TEM_pseudo3D",
         "data": ["Observed"],
-        "model": {"objects": "Inversion_VTEM_Model"},
+        "model": {"objects": "Inversion_VTEM_Model", "data": "Iteration_7_model"},
+        "lines": {"data": "Line", "lines": 6073400.0},
+        "boreholes": {"objects": "geochem", "data": "Al2O3"},
+        "doi": {"data": "Z"},
+        "doi_percent": 60,
+        "doi_revert": True,
+        "center": 0.35,
+        "width": 0.28,
+        "smoothing": 6,
+        "show_model": True,
+        "show_borehole": True,
+        "show_doi": True,
+        "slice_width": 150,
+        "x_label": "Easting",
+        "ga_group_name": "EMProfiler",
     }
 
     def __init__(self, **kwargs):
         kwargs = self.apply_defaults(**kwargs)
 
-        self.em_system_specs = geophysical_systems.parameters()
-        self._system = Dropdown(
-            options=[
-                key
-                for key, specs in self.em_system_specs.items()
-                if specs["type"] == "time"
-            ],
-            description="Time-Domain System:",
-        )
-        self._time_groups = {}
-        self.group_list = Dropdown(description="")
-        self.surface_model = None
         self.borehole_trace = None
-        self._survey = None
-        self.model_figure = go.FigureWidget()
-        self.model_figure.add_trace(go.Scatter3d())
-        self.model_figure.add_trace(go.Cone())
-        self.model_figure.add_trace(go.Mesh3d())
-        self.model_figure.add_trace(go.Scatter3d())
-        self.model_figure.update_layout(
-            scene={
-                "xaxis_title": "Easting (m)",
-                "yaxis_title": "Northing (m)",
-                "zaxis_title": "Elevation (m)",
-                "yaxis": {"autorange": "reversed"},
-                "xaxis": {"autorange": "reversed"},
-                "aspectmode": "data",
-            },
-            width=800,
-            height=400,
-            autosize=False,
-            uirevision=False,
-        )
-
-        self.marker = {"left": "<", "right": ">"}
-        self.channels = SelectMultiple(description="Channels")
-        self._group_early = Text(description="Early")
-        self._group_middle = Text(description="Middle")
-        self._group_late = Text(description="Late")
         self.data_channels = {}
         self.data_channel_options = {}
-        self.smoothing = IntSlider(
-            min=0,
-            max=64,
-            value=0,
-            description="Smoothing",
-            continuous_update=False,
-            tooltip="Running mean width",
-        )
-        self.color_maps = Dropdown(
-            description="Colormaps",
-            options=px.colors.named_colorscales(),
-            value="edge",
-        )
-        self.residual = Checkbox(description="Use residual", value=False)
-        self.threshold = FloatSlider(
-            value=50,
-            min=10,
-            max=90,
-            step=5,
-            continuous_update=False,
-            description="Decay threshold (%)",
-        )
-        self.opacity = FloatSlider(
-            value=0.9,
-            min=0.0,
-            max=1.0,
-            step=0.05,
-            continuous_update=False,
-            description="Opacity",
-        )
-        self.doi_percent = FloatSlider(
-            value=20.0,
-            min=0.0,
-            max=100.0,
-            step=0.1,
-            continuous_update=False,
-            description="DOI %",
-        )
-        self.doi_revert = Checkbox(description="Revert", value=False)
-        self.center = FloatSlider(
-            value=0.5,
-            min=0,
-            max=1.0,
-            step=0.001,
-            description="Position (%)",
-            disabled=False,
-            continuous_update=False,
-            orientation="horizontal",
-        )
-        self.shift_cox_z = FloatSlider(
-            value=0,
-            min=0,
-            max=200,
-            step=1.0,
-            description="Z shift (m)",
-            disabled=False,
-            continuous_update=False,
-            orientation="horizontal",
-        )
-        self.dip_rotation = FloatSlider(
-            value=0,
-            min=0,
-            max=90,
-            step=1.0,
-            description="Rotate dip (dd)",
-            disabled=False,
-            continuous_update=False,
-            orientation="horizontal",
-        )
-        self.slice_width = FloatSlider(
-            value=10.0,
-            min=1.0,
-            max=500.0,
-            step=1.0,
-            description="Slice width (m)",
-            disabled=False,
-            continuous_update=False,
-            orientation="horizontal",
-        )
-        self.auto_picker = ToggleButton(description="Pick nearest target", value=False)
+        self.em_system_specs = geophysical_systems.parameters()
+        self.marker = {"left": "<", "right": ">"}
         self.pause_plot_refresh = False
-        self.reverse_cmap = ToggleButton(description="Flip colormap", value=False)
-        self.focus = FloatSlider(
-            value=1.0,
-            min=0.025,
-            max=1.0,
-            step=0.005,
-            description="Width (%)",
-            disabled=False,
-            continuous_update=False,
-            orientation="horizontal",
-        )
-        self.zoom = VBox([self.center, self.focus])
-        self.scale_button = ToggleButtons(
-            options=["linear", "symlog",],
-            description="Y-axis scaling",
-            orientation="vertical",
-        )
-        self.scale_value = FloatLogSlider(
-            min=-18,
-            max=10,
-            step=0.5,
-            base=10,
-            value=1e-2,
-            description="Linear threshold",
-            continuous_update=False,
-        )
-        self.channel_selection = Dropdown(
-            description="Time Gate",
-            options=self.em_system_specs[self.system.value]["channels"].keys(),
-        )
-        self.group_add = ToggleButton(description="^ Add New Group ^")
-        self.group_name = Text(description="Name")
-        self.group_color = ColorPicker(
-            concise=False, description="Color", value="blue", disabled=False
-        )
-        self.markers = ToggleButton(description="Show markers")
-        self.groups_setter = ToggleButton(description="Select Time Groups", value=False)
-        self.x_label = ToggleButtons(
-            options=["Distance", "Easting", "Northing"],
-            value="Distance",
-            description="X-axis label:",
-            orientation="vertical",
-        )
-        self.show_model = ToggleButton(
-            description="Show model", value=False, button_style="success"
-        )
-        self.show_doi = ToggleButton(
-            description="Show DOI", value=False, button_style="success"
-        )
-        self.show_borehole = ToggleButton(
-            description="Show Boreholes", value=False, button_style="success"
-        )
-        self.show_decay = ToggleButton(description="Show decay", value=False)
-        self.lines = LineOptions(multiple_lines=False)
-        self.model_selection = ObjectDataSelection(object_types=(Surface,))
-        self.doi_selection = ObjectDataSelection()
-        self.boreholes = ObjectDataSelection(object_types=(Points,))
+        self.surface_model = None
+        self._survey = None
+        self._time_groups = {}
 
         def objects_change(_):
             self.objects_change()
 
         self.objects.observe(objects_change, names="value")
 
+        def show_model_trigger(_):
+            self.show_model_trigger()
+
+        self.model_panel = VBox([self.show_model])
+        self.show_model.observe(show_model_trigger, names="value")
+
+        def show_doi_trigger(_):
+            self.show_doi_trigger()
+
+        self.doi_panel = VBox([self.show_doi])
+        self.show_doi.observe(show_doi_trigger, names="value")
+
+        def show_borehole_trigger(_):
+            self.show_borehole_trigger()
+
+        self.borehole_panel = VBox([self.show_borehole])
+        self.show_borehole.observe(show_borehole_trigger, names="value")
+
         super().__init__(**kwargs)
 
         self.objects.description = "Survey"
@@ -257,7 +121,7 @@ class EMLineProfiler(ObjectDataSelection):
         if "boreholes" in kwargs.keys():
             self.boreholes.__populate__(**kwargs["boreholes"])
         self.boreholes.objects.description = "Borehole"
-        self.boreholes.data.description = "Markers"
+        self.boreholes.data.description = "Log"
 
         if "model" in kwargs.keys():
             self.model_selection.__populate__(**kwargs["model"])
@@ -282,9 +146,6 @@ class EMLineProfiler(ObjectDataSelection):
 
         self.scale_button.observe(scale_update)
 
-        def add_group(_):
-            self.add_group()
-
         def system_observer(_):
             self.system_observer()
 
@@ -314,6 +175,9 @@ class EMLineProfiler(ObjectDataSelection):
         self.system_box_option.observe(system_box_trigger)
         self.system_box = VBox([self.system_box_option])
 
+        def add_group(_):
+            self.add_group()
+
         self.group_add.observe(add_group)
 
         def highlight_selection(_):
@@ -331,8 +195,8 @@ class EMLineProfiler(ObjectDataSelection):
         def trigger_click(_):
             self.trigger_click()
 
-        self.trigger.observe(trigger_click)
-        self.trigger.description = "Export to GA"
+        self.trigger.on_click(trigger_click)
+        self.trigger.description = "Export Marker"
 
         def plot_data_selection(
             data,
@@ -343,7 +207,7 @@ class EMLineProfiler(ObjectDataSelection):
             scale,
             scale_value,
             center,
-            focus,
+            width,
             groups,
             pick_trigger,
             x_label,
@@ -358,7 +222,7 @@ class EMLineProfiler(ObjectDataSelection):
                 scale,
                 scale_value,
                 center,
-                focus,
+                width,
                 groups,
                 pick_trigger,
                 x_label,
@@ -376,7 +240,7 @@ class EMLineProfiler(ObjectDataSelection):
                 "scale": self.scale_button,
                 "scale_value": self.scale_value,
                 "center": self.center,
-                "focus": self.focus,
+                "width": self.width,
                 "groups": self.group_list,
                 "pick_trigger": self.auto_picker,
                 "x_label": self.x_label,
@@ -413,7 +277,7 @@ class EMLineProfiler(ObjectDataSelection):
         def plot_model_selection(
             ind,
             center,
-            focus,
+            width,
             x_label,
             colormap,
             reverse,
@@ -431,13 +295,14 @@ class EMLineProfiler(ObjectDataSelection):
             borehole_show,
             borehole_object,
             borehole_data,
+            boreholes_size,
         ):
             self.update_line_model()
             self.update_line_boreholes()
             self.plot_model_selection(
                 ind,
                 center,
-                focus,
+                width,
                 x_label,
                 colormap,
                 reverse,
@@ -445,6 +310,7 @@ class EMLineProfiler(ObjectDataSelection):
                 dip_rotation,
                 opacity,
                 doi_percent,
+                boreholes_size,
             )
 
         self.model_section = interactive_output(
@@ -452,7 +318,7 @@ class EMLineProfiler(ObjectDataSelection):
             {
                 "ind": self.lines.lines,
                 "center": self.center,
-                "focus": self.focus,
+                "width": self.width,
                 "objects": self.model_selection.objects,
                 "model": self.model_selection.data,
                 "smoothing": self.smoothing,
@@ -470,36 +336,16 @@ class EMLineProfiler(ObjectDataSelection):
                 "borehole_show": self.show_borehole,
                 "borehole_object": self.boreholes.objects,
                 "borehole_data": self.boreholes.data,
+                "boreholes_size": self.boreholes_size,
             },
         )
 
-        def show_model_trigger(_):
-            self.show_model_trigger()
-
-        self.model_panel = VBox([self.show_model])
-        self.show_model.observe(show_model_trigger, names="value")
-
-        def show_doi_trigger(_):
-            self.show_doi_trigger()
-
-        self.doi_panel = VBox([self.show_doi])
-        self.show_doi.observe(show_doi_trigger, names="value")
-
-        def show_borehole_trigger(_):
-            self.show_borehole_trigger()
-
-        self.borehole_panel = VBox([self.show_borehole])
-        self.show_borehole.observe(show_borehole_trigger, names="value")
-
         self._widget = VBox(
             [
                 self.project_panel,
                 HBox(
                     [
-                        VBox(
-                            [self.widget, self.lines.widget,],
-                            layout=Layout(width="50%"),
-                        ),
+                        VBox([self.widget,], layout=Layout(width="50%"),),
                         VBox(
                             [self.system_box, self.groups_widget, self.decay_panel,],
                             layout=Layout(width="50%"),
@@ -510,25 +356,108 @@ class EMLineProfiler(ObjectDataSelection):
                     [
                         VBox(
                             [
-                                self.zoom,
+                                self.center,
+                                self.width,
                                 self.smoothing,
                                 self.residual,
-                                self.x_label,
                                 scale_panel,
                                 self.markers,
                             ],
                             layout=Layout(width="50%"),
                         ),
-                        plotting,
+                        VBox([plotting, self.x_label,]),
                     ]
                 ),
+                Box(
+                    children=[self.lines.widget],
+                    layout=Layout(
+                        display="flex",
+                        flex_flow="row",
+                        align_items="stretch",
+                        width="100%",
+                        justify_content="center",
+                    ),
+                ),
                 self.model_panel,
-                self.trigger_widget,
+                self.trigger_panel,
             ]
         )
 
         self.auto_picker.value = True
 
+    @property
+    def auto_picker(self):
+        if getattr(self, "_auto_picker", None) is None:
+            self._auto_picker = ToggleButton(
+                description="Pick nearest target", value=False
+            )
+
+        return self._auto_picker
+
+    @property
+    def boreholes(self):
+        if getattr(self, "_boreholes", None) is None:
+            self._boreholes = ObjectDataSelection(object_types=(Points,))
+
+        return self._boreholes
+
+    @property
+    def boreholes_size(self):
+        if getattr(self, "_boreholes_size", None) is None:
+            self._boreholes_size = IntSlider(
+                value=3,
+                min=1,
+                max=20,
+                description="Marker Size",
+                continuous_update=False,
+            )
+
+        return self._boreholes_size
+
+    @property
+    def center(self):
+        if getattr(self, "_center", None) is None:
+            self._center = FloatSlider(
+                value=0.5,
+                min=0,
+                max=1.0,
+                step=0.001,
+                description="Position (%)",
+                disabled=False,
+                continuous_update=False,
+                orientation="horizontal",
+            )
+
+        return self._center
+
+    @property
+    def channels(self):
+        if getattr(self, "_channels", None) is None:
+            self._channels = SelectMultiple(description="Channels")
+
+        return self._channels
+
+    @property
+    def channel_selection(self):
+        if getattr(self, "_channel_selection", None) is None:
+            self._channel_selection = Dropdown(
+                description="Time Gate",
+                options=self.em_system_specs[self.system.value]["channels"].keys(),
+            )
+
+        return self._channel_selection
+
+    @property
+    def color_maps(self):
+        if getattr(self, "_color_maps", None) is None:
+            self._color_maps = Dropdown(
+                description="Colormaps",
+                options=px.colors.named_colorscales(),
+                value="edge",
+            )
+
+        return self._color_maps
+
     @property
     def data(self):
         """
@@ -551,6 +480,282 @@ class EMLineProfiler(ObjectDataSelection):
         self._data.observe(set_data, names="value")
         self.set_data()
 
+    @property
+    def dip_rotation(self):
+        if getattr(self, "_dip_rotation", None) is None:
+            self._dip_rotation = FloatSlider(
+                value=0,
+                min=0,
+                max=90,
+                step=1.0,
+                description="Rotate dip (dd)",
+                disabled=False,
+                continuous_update=False,
+                orientation="horizontal",
+            )
+
+        return self._dip_rotation
+
+    @property
+    def doi_percent(self):
+        if getattr(self, "_doi_percent", None) is None:
+            self._doi_percent = FloatSlider(
+                value=20.0,
+                min=0.0,
+                max=100.0,
+                step=0.1,
+                continuous_update=False,
+                description="DOI %",
+            )
+
+        return self._doi_percent
+
+    @property
+    def doi_revert(self):
+        if getattr(self, "_doi_revert", None) is None:
+            self._doi_revert = Checkbox(description="Revert", value=False)
+
+        return self._doi_revert
+
+    @property
+    def doi_selection(self):
+        if getattr(self, "_doi_selection", None) is None:
+            self._doi_selection = ObjectDataSelection()
+
+        return self._doi_selection
+
+    @property
+    def width(self):
+        if getattr(self, "_width", None) is None:
+            self._width = FloatSlider(
+                value=1.0,
+                min=0.025,
+                max=1.0,
+                step=0.005,
+                description="Width (%)",
+                disabled=False,
+                continuous_update=False,
+                orientation="horizontal",
+            )
+
+        return self._width
+
+    @property
+    def group_add(self):
+        if getattr(self, "_group_add", None) is None:
+            self._group_add = ToggleButton(description="^ Add New Group ^")
+
+        return self._group_add
+
+    @property
+    def group_color(self):
+        if getattr(self, "_group_color", None) is None:
+            self._group_color = ColorPicker(
+                concise=False, description="Color", value="blue", disabled=False
+            )
+
+        return self._group_color
+
+    @property
+    def group_list(self):
+        if getattr(self, "_group_list", None) is None:
+            self._group_list = Dropdown(description="")
+
+        return self._group_list
+
+    @property
+    def group_name(self):
+        if getattr(self, "_group_name", None) is None:
+            self._group_name = Text(description="Name")
+
+        return self._group_name
+
+    @property
+    def groups_setter(self):
+        if getattr(self, "_groups_setter", None) is None:
+            self._groups_setter = ToggleButton(
+                description="Select Time Groups", value=False
+            )
+
+        return self._groups_setter
+
+    @property
+    def lines(self):
+        if getattr(self, "_lines", None) is None:
+            self._lines = LineOptions(multiple_lines=False)
+
+        return self._lines
+
+    @property
+    def markers(self):
+        if getattr(self, "_markers", None) is None:
+            self._markers = ToggleButton(description="Show markers")
+
+        return self._markers
+
+    @property
+    def model_selection(self):
+        if getattr(self, "_model_selection", None) is None:
+            self._model_selection = ObjectDataSelection(object_types=(Surface,))
+
+        return self._model_selection
+
+    @property
+    def opacity(self):
+        if getattr(self, "_opacity", None) is None:
+            self._opacity = FloatSlider(
+                value=0.9,
+                min=0.0,
+                max=1.0,
+                step=0.05,
+                continuous_update=False,
+                description="Opacity",
+            )
+
+        return self._opacity
+
+    @property
+    def residual(self):
+        if getattr(self, "_residual", None) is None:
+            self._residual = Checkbox(description="Use residual", value=False)
+
+        return self._residual
+
+    @property
+    def reverse_cmap(self):
+        if getattr(self, "_reverse_cmap", None) is None:
+            self._reverse_cmap = ToggleButton(description="Flip colormap", value=False)
+
+        return self._reverse_cmap
+
+    @property
+    def scale_button(self):
+        if getattr(self, "_scale_button", None) is None:
+            self._scale_button = ToggleButtons(
+                options=["linear", "symlog",],
+                description="Y-axis scaling",
+                orientation="vertical",
+            )
+
+        return self._scale_button
+
+    @property
+    def scale_value(self):
+        if getattr(self, "_scale_value", None) is None:
+            self._scale_value = FloatLogSlider(
+                min=-18,
+                max=10,
+                step=0.5,
+                base=10,
+                value=1e-2,
+                description="Linear threshold",
+                continuous_update=False,
+            )
+
+        return self._scale_value
+
+    @property
+    def shift_cox_z(self):
+        if getattr(self, "_shift_cox_z", None) is None:
+            self._shift_cox_z = FloatSlider(
+                value=0,
+                min=0,
+                max=200,
+                step=1.0,
+                description="Z shift (m)",
+                disabled=False,
+                continuous_update=False,
+                orientation="horizontal",
+            )
+
+        return self._shift_cox_z
+
+    @property
+    def show_borehole(self):
+        if getattr(self, "_show_borehole", None) is None:
+            self._show_borehole = ToggleButton(
+                description="Show Boreholes", value=False, button_style="success"
+            )
+
+        return self._show_borehole
+
+    @property
+    def show_decay(self):
+        if getattr(self, "_show_decay", None) is None:
+            self._show_decay = ToggleButton(description="Show decay", value=False)
+
+        return self._show_decay
+
+    @property
+    def show_doi(self):
+        if getattr(self, "_show_doi", None) is None:
+            self._show_doi = ToggleButton(
+                description="Show DOI", value=False, button_style="success"
+            )
+
+        return self._show_doi
+
+    @property
+    def show_model(self):
+        if getattr(self, "_show_model", None) is None:
+            self._show_model = ToggleButton(
+                description="Show model", value=False, button_style="success"
+            )
+
+        return self._show_model
+
+    @property
+    def slice_width(self):
+        if getattr(self, "_slice_width", None) is None:
+            self._slice_width = FloatSlider(
+                value=10.0,
+                min=1.0,
+                max=500.0,
+                step=1.0,
+                description="Slice width (m)",
+                disabled=False,
+                continuous_update=False,
+                orientation="horizontal",
+            )
+
+        return self._slice_width
+
+    @property
+    def smoothing(self):
+        if getattr(self, "_smoothing", None) is None:
+            self._smoothing = IntSlider(
+                min=0,
+                max=64,
+                value=0,
+                description="Smoothing",
+                continuous_update=False,
+                tooltip="Running mean width",
+            )
+
+        return self._smoothing
+
+    @property
+    def survey(self):
+        """
+
+        """
+
+        return self._survey
+
+    @property
+    def system(self):
+        if getattr(self, "__system", None) is None:
+            self._system = Dropdown(
+                options=[
+                    key
+                    for key, specs in self.em_system_specs.items()
+                    if specs["type"] == "time"
+                ],
+                description="Time-Domain System:",
+            )
+
+        return self._system
+
     @property
     def time_groups(self):
 
@@ -573,40 +778,18 @@ class EMLineProfiler(ObjectDataSelection):
         self._time_groups = groups
 
     @property
-    def survey(self):
-        """
+    def threshold(self):
+        if getattr(self, "_threshold", None) is None:
+            self._threshold = FloatSlider(
+                value=50,
+                min=10,
+                max=90,
+                step=5,
+                continuous_update=False,
+                description="Decay threshold (%)",
+            )
 
-        """
-
-        return self._survey
-
-    @property
-    def system(self):
-        """
-
-        """
-        return self._system
-
-    @property
-    def group_early(self):
-        """
-
-        """
-        return self._group_early
-
-    @property
-    def group_middle(self):
-        """
-
-        """
-        return self._group_middle
-
-    @property
-    def group_middle(self):
-        """
-
-        """
-        return self._group_middle
+        return self._threshold
 
     @property
     def workspace(self):
@@ -637,6 +820,20 @@ class EMLineProfiler(ObjectDataSelection):
         self.doi_selection.objects = self.model_selection.objects
         self.doi_selection.workspace = workspace
 
+        self.reset_model_figure()
+
+    @property
+    def x_label(self):
+        if getattr(self, "_x_label", None) is None:
+            self._x_label = ToggleButtons(
+                options=["Distance", "Easting", "Northing"],
+                value="Distance",
+                description="X-axis label:",
+                orientation="horizontal",
+            )
+
+        return self._x_label
+
     def set_data(self):
         if getattr(self, "survey", None) is not None:
             groups = [p_g.name for p_g in self.survey.property_groups]
@@ -667,7 +864,6 @@ class EMLineProfiler(ObjectDataSelection):
             self.auto_picker.value = True
 
     def objects_change(self):
-
         if self.workspace.get_entity(self.objects.value):
             self._survey = self.workspace.get_entity(self.objects.value)[0]
 
@@ -680,7 +876,27 @@ class EMLineProfiler(ObjectDataSelection):
                 ):
                     self.system.value = aem_system
 
-            # self.line_update()
+    def reset_model_figure(self):
+        self.model_figure = go.FigureWidget()
+        self.model_figure.add_trace(go.Scatter3d())
+        self.model_figure.add_trace(go.Cone())
+        self.model_figure.add_trace(go.Mesh3d())
+        self.model_figure.add_trace(go.Scatter3d())
+        self.model_figure.update_layout(
+            scene={
+                "xaxis_title": "Easting (m)",
+                "yaxis_title": "Northing (m)",
+                "zaxis_title": "Elevation (m)",
+                "yaxis": {"autorange": "reversed"},
+                "xaxis": {"autorange": "reversed"},
+                "aspectmode": "data",
+            },
+            width=700,
+            height=500,
+            autosize=False,
+            uirevision=False,
+        )
+        self.show_model.value = False
 
     def system_box_trigger(self):
         if self.system_box_option.value:
@@ -771,63 +987,60 @@ class EMLineProfiler(ObjectDataSelection):
             self.group_add.value = False
 
     def trigger_click(self):
-        if self.trigger.value:
-            # for group in self.group_list.value:
-            group = self.group_list.value
-            tau = self.time_groups[group]["mad_tau"]
-            dip = self.time_groups[group]["dip"]
-            azimuth = self.time_groups[group]["azimuth"]
-            cox = self.time_groups[group]["cox"]
-            cox[2] -= self.shift_cox_z.value
 
-            if self.workspace.get_entity(group):
-                points = self.workspace.get_entity(group)[0]
-                azm_data = points.get_data("azimuth")[0]
-                azm_vals = azm_data.values.copy()
-                dip_data = points.get_data("dip")[0]
-                dip_vals = dip_data.values.copy()
+        # for group in self.group_list.value:
+        group = self.group_list.value
+        tau = self.time_groups[group]["mad_tau"]
+        dip = self.time_groups[group]["dip"]
+        azimuth = self.time_groups[group]["azimuth"]
+        cox = self.time_groups[group]["cox"]
+        cox[2] -= self.shift_cox_z.value
 
-                tau_data = points.get_data("tau")[0]
-                tau_vals = tau_data.values.copy()
+        points = [child for child in self.ga_group.children if child.name == group]
+        if any(points):
+            points = points[0]
+            azm_data = points.get_data("azimuth")[0]
+            azm_vals = azm_data.values.copy()
+            dip_data = points.get_data("dip")[0]
+            dip_vals = dip_data.values.copy()
 
-                points.vertices = np.vstack([points.vertices, cox.reshape((1, 3))])
-                azm_data.values = np.hstack([azm_vals, azimuth])
-                dip_data.values = np.hstack([dip_vals, dip])
-                tau_data.values = np.hstack([tau_vals, tau])
+            tau_data = points.get_data("tau")[0]
+            tau_vals = tau_data.values.copy()
 
-            else:
-                # if self.workspace.get_entity(group)
-                # parent =
-                points = Points.create(
-                    self.workspace, name=group, vertices=cox.reshape((1, 3))
-                )
-                points.add_data(
-                    {
-                        "azimuth": {"values": np.asarray(azimuth)},
-                        "dip": {"values": np.asarray(dip)},
-                        "tau": {"values": np.asarray(tau)},
-                    }
-                )
-                group = points.find_or_create_property_group(
-                    name="AzmDip", property_group_type="Dip direction & dip"
-                )
-                group.properties = [
-                    points.get_data("azimuth")[0].uid,
-                    points.get_data("dip")[0].uid,
-                ]
+            points.vertices = np.vstack([points.vertices, cox.reshape((1, 3))])
+            azm_data.values = np.hstack([azm_vals, azimuth])
+            dip_data.values = np.hstack([dip_vals, dip])
+            tau_data.values = np.hstack([tau_vals, tau])
 
-            if self.live_link.value:
-                if not os.path.exists(self.live_link_path.value):
-                    os.mkdir(self.live_link_path.value)
+        else:
+            # if self.workspace.get_entity(group)
+            # parent =
+            points = Points.create(
+                self.workspace,
+                name=group,
+                vertices=cox.reshape((1, 3)),
+                parent=self.ga_group,
+            )
+            points.entity_type.name = group
+            points.add_data(
+                {
+                    "azimuth": {"values": np.asarray(azimuth)},
+                    "dip": {"values": np.asarray(dip)},
+                    "tau": {"values": np.asarray(tau)},
+                }
+            )
+            group = points.find_or_create_property_group(
+                name="AzmDip", property_group_type="Dip direction & dip"
+            )
+            group.properties = [
+                points.get_data("azimuth")[0].uid,
+                points.get_data("dip")[0].uid,
+            ]
 
-                temp_geoh5 = os.path.join(
-                    self.live_link_path.value, f"temp{time.time():.3f}.geoh5"
-                )
-                ws_out = Workspace(temp_geoh5)
-                points.copy(parent=ws_out)
+        if self.live_link.value:
+            self.live_link_output(points)
 
-            self.trigger.value = False
-            self.workspace.finalize()
+        self.workspace.finalize()
 
     def highlight_selection(self):
         """
@@ -851,7 +1064,7 @@ class EMLineProfiler(ObjectDataSelection):
         scale,
         scale_value,
         center,
-        focus,
+        width,
         groups,
         pick_trigger,
         x_label,
@@ -880,15 +1093,12 @@ class EMLineProfiler(ObjectDataSelection):
         lims = np.searchsorted(
             self.lines.profile.locations_resampled,
             [
-                (center - focus / 2.0) * self.lines.profile.locations_resampled[-1],
-                (center + focus / 2.0) * self.lines.profile.locations_resampled[-1],
+                (center - width / 2.0) * self.lines.profile.locations_resampled[-1],
+                (center + width / 2.0) * self.lines.profile.locations_resampled[-1],
             ],
         )
-
         sub_ind = np.arange(lims[0], lims[1])
 
-        # channels = []
-        # for group in self.group_list.value:
         try:
             time_group = self.time_groups[self.group_list.value]
             channels = time_group["channels"]
@@ -923,7 +1133,7 @@ class EMLineProfiler(ObjectDataSelection):
                 continue
 
             if axs is None:
-                fig = plt.figure(figsize=(12, 8))
+                fig = plt.figure(figsize=(12, 6))
                 axs = plt.subplot()
 
             self.lines.profile.values = d.values[self.survey.line_indices].copy()
@@ -1073,14 +1283,11 @@ class EMLineProfiler(ObjectDataSelection):
             peaks = np.vstack(time_group["peaks"])
             inflx_dwn = np.vstack(time_group["inflx_dwn"])
             inflx_up = np.vstack(time_group["inflx_up"])
-
             ratio = peaks[:, 1] / peaks[0, 1]
             ind = np.where(ratio >= (1 - threshold / 100))[0][-1]
-
             peaks = np.mean(peaks[: ind + 1, :], axis=0)
             inflx_dwn = np.mean(inflx_dwn[: ind + 1, :], axis=0)
             inflx_up = np.mean(inflx_up[: ind + 1, :], axis=0)
-
             cox_x = self.lines.profile.interp_x(peaks[0])
             cox_y = self.lines.profile.interp_y(peaks[0])
             cox_z = self.lines.profile.interp_z(peaks[0])
@@ -1149,15 +1356,14 @@ class EMLineProfiler(ObjectDataSelection):
                 plt.yscale("symlog", linthreshy=scale_value)
 
             x_lims = [
-                center_x - focus / 2.0 * self.lines.profile.locations_resampled[-1],
-                center_x + focus / 2.0 * self.lines.profile.locations_resampled[-1],
+                center_x - width / 2.0 * self.lines.profile.locations_resampled[-1],
+                center_x + width / 2.0 * self.lines.profile.locations_resampled[-1],
             ]
             axs.set_xlim(x_lims)
             axs.set_title(f"Line: {ind}")
             axs.set_ylabel("dBdT")
 
             if x_label == "Easting":
-
                 axs.text(
                     center_x,
                     0,
@@ -1172,6 +1378,7 @@ class EMLineProfiler(ObjectDataSelection):
                 ]
                 axs.set_xticklabels(xlbl)
                 axs.set_xlabel("Easting (m)")
+
             elif x_label == "Northing":
                 axs.text(
                     center_x,
@@ -1187,6 +1394,7 @@ class EMLineProfiler(ObjectDataSelection):
                 ]
                 axs.set_xticklabels(xlbl)
                 axs.set_xlabel("Northing (m)")
+
             else:
                 axs.text(
                     center_x,
@@ -1231,9 +1439,7 @@ class EMLineProfiler(ObjectDataSelection):
             a, c = np.linalg.solve(np.dot(A.T, A), np.dot(A.T, vals))
             d = np.r_[tc.min(), tc.max()]
             vv = d * c + a
-
             ratio = np.abs((vv[0] - vv[1]) / (d[0] - d[1]))
-            #                 angl = np.arctan(ratio**-1.)
 
             self.time_groups[group]["mad_tau"] = ratio ** -1.0
 
@@ -1275,7 +1481,7 @@ class EMLineProfiler(ObjectDataSelection):
         self,
         ind,
         center,
-        focus,
+        width,
         x_label,
         colormap,
         reverse,
@@ -1283,6 +1489,7 @@ class EMLineProfiler(ObjectDataSelection):
         dip_rotation,
         opacity,
         doi_percent,
+        boreholes_size,
     ):
         if (
             getattr(self, "survey", None) is None
@@ -1314,6 +1521,11 @@ class EMLineProfiler(ObjectDataSelection):
             self.model_figure.data[0].y = self.lines.model_vertices[ind, 1]
             self.model_figure.data[0].z = self.lines.model_vertices[ind, 2]
             self.model_figure.data[0].mode = "markers"
+            self.model_figure.data[0].marker = {
+                "symbol": "diamond",
+                "color": "black",
+                "size": 5,
+            }
 
             # for group in self.group_list.value:
             group = self.group_list.value
@@ -1369,11 +1581,10 @@ class EMLineProfiler(ObjectDataSelection):
                 self.model_figure.data[3].y = self.lines.borehole_vertices[:, 1]
                 self.model_figure.data[3].z = self.lines.borehole_vertices[:, 2]
                 self.model_figure.data[3].mode = "markers"
+                self.model_figure.data[3].marker.size = boreholes_size
 
                 if getattr(self.lines, "borehole_values", None) is not None:
-                    self.model_figure.data[3].marker = {
-                        "color": self.lines.borehole_values
-                    }
+                    self.model_figure.data[3].marker.color = self.lines.borehole_values
 
             self.model_figure.show()
 
@@ -1432,9 +1643,9 @@ class EMLineProfiler(ObjectDataSelection):
         ):
 
             lims = [
-                (self.center.value - self.focus.value / 2.0)
+                (self.center.value - self.width.value / 2.0)
                 * self.lines.profile.locations_resampled[-1],
-                (self.center.value + self.focus.value / 2.0)
+                (self.center.value + self.width.value / 2.0)
                 * self.lines.profile.locations_resampled[-1],
             ]
             x_locs = self.lines.profile.x_locs
@@ -1631,6 +1842,7 @@ class EMLineProfiler(ObjectDataSelection):
                 self.show_borehole,
                 self.boreholes.widget,
                 self.slice_width,
+                self.boreholes_size,
             ]
             self.show_borehole.description = "Hide Boreholes"
         else:
